@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Author;
 # ABSTRACT: An Author data object
-$MetaCPAN::Client::Author::VERSION = '2.007000';
+$MetaCPAN::Client::Author::VERSION = '2.008000';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -66,6 +66,8 @@ sub releases {
 
 sub dir { $_[0]->links->{cpan_directory} }
 
+sub metacpan_url { "https://metacpan.org/author/" . $_[0]->pauseid }
+
 1;
 
 __END__
@@ -80,7 +82,7 @@ MetaCPAN::Client::Author - An Author data object
 
 =head1 VERSION
 
-version 2.007000
+version 2.008000
 
 =head1 SYNOPSIS
 
@@ -268,6 +270,10 @@ This method returns a L<MetaCPAN::Client::ResultSet> of
 L<MetaCPAN::Client::Release> objects. It includes all of the author's releases
 with the C<latest> status.
 
+=head2 metacpan_url
+
+Returns a link to the author's page on MetaCPAN.
+
 =head1 AUTHORS
 
 =over 4
