@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Distribution;
 # ABSTRACT: A Distribution data object
-$MetaCPAN::Client::Distribution::VERSION = '2.007000';
+$MetaCPAN::Client::Distribution::VERSION = '2.008000';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -42,6 +42,8 @@ sub _known_fields { return \%known_fields }
 sub rt     { $_[0]->bugs->{rt}     || {} }
 sub github { $_[0]->bugs->{github} || {} }
 
+sub metacpan_url { "https://metacpan.org/release/" . $_[0]->name }
+
 1;
 
 __END__
@@ -56,7 +58,7 @@ MetaCPAN::Client::Distribution - A Distribution data object
 
 =head1 VERSION
 
-version 2.007000
+version 2.008000
 
 =head1 SYNOPSIS
 
@@ -116,6 +118,10 @@ hashref.
 Returns the hashref of data for the github bug tracker. This defaults to an
 empty hashref.
 
+=head2 metacpan_url
+
+Returns a link to the distribution page on MetaCPAN.
+
 =head1 AUTHORS
 
 =over 4
