@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::File;
 # ABSTRACT: A File data object
-$MetaCPAN::Client::File::VERSION = '2.007000';
+$MetaCPAN::Client::File::VERSION = '2.008000';
 use Moo;
 use Carp;
 
@@ -90,6 +90,12 @@ sub source {
         );
 }
 
+sub metacpan_url {
+    my $self = shift;
+    sprintf("https://metacpan.org/source/%s/%s/%s",
+            $self->author, $self->release, $self->path );
+}
+
 1;
 
 __END__
@@ -104,7 +110,7 @@ MetaCPAN::Client::File - A File data object
 
 =head1 VERSION
 
-version 2.007000
+version 2.008000
 
 =head1 DESCRIPTION
 
@@ -292,6 +298,10 @@ Supported types: B<plain>, B<html>, B<x-pod>, B<x-markdown>.
 
 Returns the source code for the file.
 
+=head2 metacpan_url
+
+Returns a link to the file source page on MetaCPAN.
+
 =head1 AUTHORS
 
 =over 4
