@@ -2,10 +2,16 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Module;
 # ABSTRACT: A Module data object
-$MetaCPAN::Client::Module::VERSION = '2.007000';
+$MetaCPAN::Client::Module::VERSION = '2.008000';
 use Moo;
 extends 'MetaCPAN::Client::File';
 
+sub metacpan_url {
+    my $self = shift;
+    sprintf("https://metacpan.org/pod/release/%s/%s/%s",
+            $self->author, $self->release, $self->path );
+}
+
 1;
 
 __END__
@@ -20,7 +26,7 @@ MetaCPAN::Client::Module - A Module data object
 
 =head1 VERSION
 
-version 2.007000
+version 2.008000
 
 =head1 SYNOPSIS
 
@@ -36,6 +42,12 @@ This is currently the exact same as L<MetaCPAN::Client::File>.
 
 Whatever L<MetaCPAN::Client::File> has.
 
+=head1 METHODS
+
+=head2 metacpan_url
+
+Returns a link to the module page on MetaCPAN.
+
 =head1 AUTHORS
 
 =over 4
