@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Release;
 # ABSTRACT: A Release data object
-$MetaCPAN::Client::Release::VERSION = '2.007000';
+$MetaCPAN::Client::Release::VERSION = '2.008000';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -55,6 +55,11 @@ foreach my $field (@known_fields) {
 
 sub _known_fields { return \%known_fields }
 
+sub metacpan_url {
+    my $self = shift;
+    sprintf( "https://metacpan.org/release/%s/%s", $self->author, $self->name )
+}
+
 1;
 
 __END__
@@ -69,7 +74,7 @@ MetaCPAN::Client::Release - A Release data object
 
 =head1 VERSION
 
-version 2.007000
+version 2.008000
 
 =head1 SYNOPSIS
 
@@ -212,6 +217,12 @@ Returns a hashref of information about CPAN testers results for this
 release. The keys are C<pass>, C<fail>, C<unknown>, and C<na>. The values are
 the count of that particular result on CPAN Testers for this release.
 
+=head1 METHODS
+
+=head2 metacpan_url
+
+Returns a link to the release page on MetaCPAN.
+
 =head1 AUTHORS
 
 =over 4
